==> feature-0.16-sources.jar: boofcv/abst/feature/associate/WrapAssociateSurfBasic.java <==
/*
 * Copyright (c) 2011-2013, Peter Abeles. All Rights Reserved.
 *
 * This file is part of BoofCV (http://boofcv.org).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package boofcv.abst.feature.associate;

import boofcv.alg.feature.associate.AssociateSurfBasic;
import boofcv.alg.feature.associate.FindUnassociated;
import boofcv.struct.feature.AssociatedIndex;
import boofcv.struct.feature.MatchScoreType;
import boofcv.struct.feature.SurfFeature;
import org.ddogleg.struct.FastQueue;
import org.ddogleg.struct.GrowQueue_I32;

/**
 * Wrapper around {@Link AssociateSurfBasic} for {@link AssociateDescription}.
 *
 * @author Peter Abeles
 */
public class WrapAssociateSurfBasic implements AssociateDescription<SurfFeature> {

	AssociateSurfBasic alg;

	// creates a list of unassociated features from the list of matches
	FindUnassociated unassociated = new FindUnassociated();

	public WrapAssociateSurfBasic(AssociateSurfBasic alg) {
		this.alg = alg;
	}

	@Override
	public void setSource(FastQueue<SurfFeature> listSrc) {
		alg.setSrc(listSrc);
	}

	@Override
	public void setDestination(FastQueue<SurfFeature> listDst) {
		alg.setDst(listDst);
	}

	@Override
	public void associate() {
		alg.associate();
	}

	@Override
	public FastQueue<AssociatedIndex> getMatches() {
		return alg.getMatches();
	}

	@Override
	public GrowQueue_I32 getUnassociatedSource() {
		return alg.getUnassociatedSrc();
	}

	@Override
	public GrowQueue_I32 getUnassociatedDestination() {
		return unassociated.checkDestination(alg.getMatches(),alg.totalDestination());
	}

	@Override
	public void setThreshold(double score) {
		alg.getAssoc().setThreshold(score);
	}

	@Override
	public MatchScoreType getScoreType() {
		return alg.getAssoc().getScoreType();
	}

	@Override
	public boolean uniqueSource() {
		return alg.getAssoc().uniqueSource();
	}

	@Override
	public boolean uniqueDestination() {
		return alg.getAssoc().uniqueDestination();
	}
}

==> feature-0.17-sources.jar: boofcv/abst/feature/associate/WrapAssociateSurfBasic.java <==
/*
 * Copyright (c) 2011-2013, Peter Abeles. All Rights Reserved.
 *
 * This file is part of BoofCV (http://boofcv.org).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package boofcv.abst.feature.associate;

import boofcv.alg.feature.associate.AssociateSurfBasic;
import boofcv.alg.feature.associate.FindUnassociated;
import boofcv.struct.feature.AssociatedIndex;
import boofcv.struct.feature.MatchScoreType;
import boofcv.struct.feature.SurfFeature;
import org.ddogleg.struct.FastQueue;
import org.ddogleg.struct.GrowQueue_I32;

/**
 * Wrapper around {@link AssociateSurfBasic} for {@link AssociateDescription}.
 *
 * @author Peter Abeles
 */
public class WrapAssociateSurfBasic implements AssociateDescription<SurfFeature> {

	AssociateSurfBasic alg;

	// creates a list of unassociated features from the list of matches
	FindUnassociated unassociated = new FindUnassociated();

	public WrapAssociateSurfBasic(AssociateSurfBasic alg) {
		this.alg = alg;
	}

	@Override
	public void setSource(FastQueue<SurfFeature> listSrc) {
		alg.setSrc(listSrc);
	}

	@Override
	public void setDestination(FastQueue<SurfFeature> listDst) {
		alg.setDst(listDst);
	}

	@Override
	public void associate() {
		alg.associate();
	}

	@Override
	public FastQueue<AssociatedIndex> getMatches() {
		return alg.getMatches();
	}

	@Override
	public GrowQueue_I32 getUnassociatedSource() {
		return alg.getUnassociatedSrc();
	}

	@Override
	public GrowQueue_I32 getUnassociatedDestination() {
		return unassociated.checkDestination(alg.getMatches(),alg.totalDestination());
	}

	@Override
	public void setThreshold(double score) {
		alg.getAssoc().setThreshold(score);
	}

	@Override
	public MatchScoreType getScoreType() {
		return alg.getAssoc().getScoreType();
	}

	@Override
	public boolean uniqueSource() {
		return alg.getAssoc().uniqueSource();
	}

	@Override
	public boolean uniqueDestination() {
		return alg.getAssoc().uniqueDestination();
	}
}
